@@ -10,7 +10,8 @@ MSI_MAPPINGS = {
 }
 
 # Build up the manifest iteratively because almost everything is optional
-def extract_metadata(data, prefix, files, infile, log: Logger):
+def extract_metadata(data, prefix, files, infile, ingest_status, log: Logger):
+
     metadata = {}
 
     test_details = data["testDetails"]
@@ -22,7 +23,7 @@ def extract_metadata(data, prefix, files, infile, log: Logger):
 
     patient = data["patientInformation"]
     metadata["bodySiteSystem"] = "http://carislifesciences.com/bodySite"
-    metadata["patientIdentifier"] = patient["mrn"]
+    metadata["mrn"] = patient["mrn"]
     metadata["patientLastName"] = patient["lastName"]
 
     metadata["patientDOB"] = patient["dob"]
@@ -49,11 +50,11 @@ def extract_metadata(data, prefix, files, infile, log: Logger):
                 {
                     "codingCode": "MR",
                     "codingSystem": "http://hl7.org/fhir/v2/0203",
-                    "value": metadata["patientIdentifier"],
+                    "value": metadata["mrn"],
                 }
             ],
         }
-        if metadata["patientIdentifier"]
+        if metadata["mrn"]
         else {
             "lastName": metadata["patientLastName"],
             "dob": metadata["patientDOB"],
@@ -75,10 +76,6 @@ def extract_metadata(data, prefix, files, infile, log: Logger):
     tmbScore = None
     ihc_run_count = 0
     tmbUnit = None
-    global EXOME_PERFORMED
-    global CNV_PERFORMED
-    global STRUCTURAL_PERFORMED
-    global IHC_PERFORMED
 
     i = 0
     # if not sufficient quantity we won't have test results
@@ -90,7 +87,7 @@ def extract_metadata(data, prefix, files, infile, log: Logger):
                 and test["testMethodology"] == "Seq"
             ):
                 # They don't always do exome sequencing
-                EXOME_PERFORMED = True
+                ingest_status["exome_performed"] = True
                 for info in test["testResults"]:
                     if "tumorMutationBurden" in info.keys():
                         tmb = info["tumorMutationBurden"]["mutationBurdenCall"].lower()
@@ -123,17 +120,17 @@ def extract_metadata(data, prefix, files, infile, log: Logger):
             elif (
                 "CNA" in test["testName"] or "CND" in test["testName"]
             ) and "test_cancellation_reason" not in test.keys():
-                CNV_PERFORMED = True
+                ingest_status["cnv_performed"] = True
                 log.info(f"Copy Number Alteration testing identified: {test['testName']} ")
             elif (
                 "Transcriptome" in test["testName"]
                 and "test_cancellation_reason" not in test.keys()
             ):
-                STRUCTURAL_PERFORMED = True
+                ingest_status["structural_performed"] = True
                 log.info(f"Structural Variant testing identified: {test['testName']}")
             # elif ("PD-L1" in test['testName'] or "Mismatch Repair Status" in test['testName']) and 'test_cancellation_reason' not in test.keys():
             elif "IHC" in test["testMethodology"] and "test_cancellation_reason" not in test.keys():
-                IHC_PERFORMED = True
+                ingest_status["ihc_performed"] = True
                 ihc_run_count += 1
                 #  if ihc_run_count <=1:
                 #      metadata['ihc']= immunohistochemistry(prefix, data)
