@@ -1,12 +1,14 @@
 from curses import meta
 import tempfile
 import json
+from threading import local
 from unittest import mock
 from ingestion.caris.util.metadata import extract_metadata
 from ingestion.caris.util.structural import extract_structural
 from ingestion.caris.util.cnv import extract_cnv
-from ingestion.caris.util.json import process_caris_json
+from ingestion.caris.process import process_caris
 from ingestion.caris.util.ga4gh import create_yaml
+from pathlib import Path
 import os
 import pandas as pd
 
@@ -39,23 +41,10 @@ mock_log = MockLog()
 
 def test_json():
     local_output_dir = tempfile.mkdtemp()
-    os.makedirs(f"{local_output_dir}", exist_ok=True)
     tar = f"{BASE_PATH}/resources/carisSample.tar.gz"
-    result = process_caris_json(tar, local_output_dir, INGEST_STATUS, mock_log)
-
-    extensions = [
-        "copynumber.csv",
-        "expression.rgel.gz",
-        "ga4gh.tmp",
-        "germline.vcf.gz",
-        "runner",
-        "structural.csv",
-    ]
-
-    for extension in extensions:
-        os.remove(f"{BASE_PATH}/resources/carisSample.{extension}")
-
-    assert "somatic_vcf" or "germline_vcf" in result
+    process_caris(tar, local_output_dir, "carisSample")
+    resulting_files = [path.name for path in Path(f"{local_output_dir}").iterdir()]
+    assert "carisSample.ga4gh.tmp" in resulting_files
 
 
 def test_extract_metadata():
@@ -64,14 +53,14 @@ def test_extract_metadata():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
 
     assert metadata == {
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
@@ -277,14 +266,14 @@ def test_handle_equivocal():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
 
     assert metadata == {
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
@@ -323,14 +312,14 @@ def test_handle_msi_unknown():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
 
     assert metadata == {
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
@@ -369,7 +358,7 @@ def test_handle_empty_test():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
 
     print(metadata)
@@ -377,7 +366,7 @@ def test_handle_empty_test():
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
@@ -413,13 +402,13 @@ def test_equivocal_status():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
     assert metadata == {
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
@@ -457,14 +446,14 @@ def test_high_status():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
 
     assert metadata == {
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
@@ -502,14 +491,14 @@ def test_qns_long_status():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
 
     assert metadata == {
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
@@ -547,14 +536,14 @@ def test_qns_status():
     data = all_data
     f.close()
     metadata = extract_metadata(
-        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", mock_log
+        data, "unit-test", {"pdf": "unit_test.pdf"}, "unit-test.tar.gz", INGEST_STATUS, mock_log
     )
 
     assert metadata == {
         "testType": "MI Profile",
         "indexedDate": "2020-12-08",
         "bodySiteSystem": "http://carislifesciences.com/bodySite",
-        "patientIdentifier": "LO-CARIS-1234",
+        "mrn": "LO-CARIS-1234",
         "patientLastName": "Smith",
         "patientDOB": "1950-10-10",
         "patientFirstName": "Jane",
